Index: trunk/src/org/openstreetmap/josm/tools/ExceptionUtil.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/ExceptionUtil.java	(revision 15085)
+++ trunk/src/org/openstreetmap/josm/tools/ExceptionUtil.java	(revision 15089)
@@ -2,5 +2,4 @@
 package org.openstreetmap.josm.tools;
 
-import static org.openstreetmap.josm.tools.I18n.marktr;
 import static org.openstreetmap.josm.tools.I18n.tr;
 import static org.openstreetmap.josm.tools.I18n.trn;
@@ -14,6 +13,8 @@
 import java.text.DateFormat;
 import java.text.ParseException;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Date;
+import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
@@ -45,8 +46,12 @@
 
     /**
-     * Error message sent by the OSM API when a user has been blocked.
-     */
-    private static final String OSM_API_BLOCKED =
-            marktr("Your access to the API has been blocked. Please log-in to the web interface to find out more.");
+     * Error messages sent by the OSM API when a user has been blocked/suspended.
+     */
+    private static final List<String> OSM_API_BLOCK_MESSAGES = Arrays.asList(
+            "You have an urgent message on the OpenStreetMap web site. " +
+                    "You need to read the message before you will be able to save your edits.",
+            "Your access to the API has been blocked. Please log-in to the web interface to find out more.",
+            "Your access to the API is temporarily suspended. Please log-in to the web interface to view the Contributor Terms." +
+                    " You do not need to agree, but you must view them.");
 
     private ExceptionUtil() {
@@ -723,11 +728,11 @@
 
     /**
      * Determines if the OSM API exception has been thrown because user has been blocked.
      * @param e OSM API exception
      * @return {@code true} if the OSM API exception has been thrown because user has been blocked
      * @since 15084
      */
     public static boolean isUserBlocked(OsmApiException e) {
-        return OSM_API_BLOCKED.equals(e.getErrorHeader());
+        return OSM_API_BLOCK_MESSAGES.contains(e.getErrorHeader());
     }
 
@@ -723,11 +728,11 @@
 
     /**
-     * Determines if the OSM API exception has been thrown because user has been blocked.
+     * Determines if the OSM API exception has been thrown because user has been blocked or suspended.
      * @param e OSM API exception
@@ -723,11 +728,11 @@
      * @param e OSM API exception
-     * @return {@code true} if the OSM API exception has been thrown because user has been blocked
+     * @return {@code true} if the OSM API exception has been thrown because user has been blocked or suspended
      * @since 15084
      */
